#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2021 Narda Safety Test Solutions GmbH.
## Contact: http://www.narda-sts.de
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################


import wx
import datetime
from nardascripting.base.usrscriptbase import *
from nardascripting.base.signalsharkdev import *
import nardascripting.base.toolbox as TB


class Example02(UsrScriptBase):
    """User script class"""

    def __init__(self, main_gui, dev=SignalSharkDev()):
        """Initialization. Please leave this line unchanged"""
        super().__init__(main_gui, dev, __file__)

        # Script settings. Please adapt this code to your needs.
        self._tab_name = "Examples"
        self._scr_title = "Example - Python Basics"
        self._scr_description = "Contains basic explanation of the Python scripting language"
        # self._icon_path = self.script_path.joinpath("NardaScriptLauncher_example01.png")
        self._list_prio = 0
        self._nsl_executed_behavior = NSL_Executed_Behaviors.SHOW_NSL

    def _run_script(self, args):
        """
        Script main function
        This method is called when a user clicks on the corresponding script button.
        """

        # Please Note: We are not responsible for the content of any 3rd party website mentioned in this code!

        # -------------------------------------------------------------------------------------------------------------
        # To start the NardaScriptLauncher and debug your code:
        # -------------------------------------------------------------------------------------------------------------
        # 1.) Right click on 'startmain.py' in the 'NardaUserScripts' project tree
        # 2.) Select "Debug 'startmain'"

        # -------------------------------------------------------------------------------------------------------------
        # Python basics
        # -------------------------------------------------------------------------------------------------------------
        #

        # -------------------------------------------------------------------------------------------------------------
        # Python: Comments:
        # -------------------------------------------------------------------------------------------------------------
        # Single line comments start with a hashtag '#'

        """
        Several lines of comments are surrounded by three quotes
        Line 2
        Line 3
        """

        # -------------------------------------------------------------------------------------------------------------
        # Python: Constans:
        # -------------------------------------------------------------------------------------------------------------
        # --> There are no constants in Python. Simply use a variable

        # -------------------------------------------------------------------------------------------------------------
        # Python: Variables
        # -------------------------------------------------------------------------------------------------------------
        # You can simply choose a name and assign a value to it.
        # A variable name can't start with a number, should be lowercase and can be separated with underscore.
        bool_var = True  # A boolean assignment
        integer_var = 100  # An integer assignment
        floating_var = 1000.0  # A floating point
        string_var = "John"  # A string variable
        list_var = [1, 2, 3, 4]  # A list of integers

        # -------------------------------------------------------------------------------------------------------------
        # Python: Decisions
        # -------------------------------------------------------------------------------------------------------------
        # You can control the program sequence with conditions:
        # Unlike C / C++ which utilizes braces for code blocks, Python code blocks are separated by indentations (tabs)

        switch_on = True
        counter = 50

        if switch_on:
            print("on")
        elif counter < 50:
            print("< 50")
        else:
            print("off")

        # -------------------------------------------------------------------------------------------------------------
        # Python: Loops
        # -------------------------------------------------------------------------------------------------------------
        # You can repeat parts of your program with loops:

        # Repeats the indented code until i reaches 50
        i = 0
        while i <= 50:
            print(i)
            i += 1

        # You can also define a range to loop through
        # This example repeats the indented code until i reaches 50 starting with i = 10
        for i in range(10, 50):
            print(i)

        # You can loop through lists
        items = ["bike ", "car", "truck"]
        for item in items:
            print(item)

            # You can break a loop by condition
            items = ["bike ", "car", "truck"]
        for item in items:
            print(item)
            if item == "car":
                break

        # You can continue a loop by condition
        items = ["bike ", "car", "do not print me", "truck"]
        for item in items:
            if item == "do not print me":
                continue
            print(item)

        # -------------------------------------------------------------------------------------------------------------
        # Python: Methods
        # -------------------------------------------------------------------------------------------------------------
        # You can divide a complex program sequence into several methods.
        # This makes the code easier to understand/maintain and you can reuse some sequences in your code
        result, arg1, arg2 = self.MyMethod(5)

    # A Method definition must be indented more left, starts with the keyword 'def' and has a colon
    #
    # You can pass some arguments to your method.
    # For class methods (like most NardaScriptLauncher methods), the first argument must be the keyword 'self'
    #
    # A Python method can return none, one or several values
    #
    # You can add a description to your method surrounding the comment text by three quotes.
    # This is called a docstring
    # Unlike C/C++, Python comments are place below the method definition

    def MyMethod(self, arg1: int, arg2="Text"):
        """

        :param arg1: This argument must be of type integer
        :param arg2: This argument must be of type string and has the default value "Text"
        :return: Returns the concatenated result and both arguments
        """
        result = arg2 + str(arg1)  # Concatenates the text argument with the numeric argument
        return result, arg1, arg2
